## Release Notes for 1.6

Released on 20 February 2022

This release does not introduce any major new features, but is instead a collection of minor improvements and tweaks based on user requests. There are also a number of changes under the hood to improve the structure and performance of novelWriter.

Some key improvements to the user interface are:

✓ The max text width setting in Preferences now also applies to the document viewer, and the setting itself on the Preference dialog has been simplified a bit.

✓ When text is selected in the document editor, the number of words selected is displayed in the editor's footer area.

✓ The search tool in the document editor now shows the number of results in the document.

✓ The Enter and Ctrl+O keyboard shortcuts should now work the same way in all tree views.

✓ It is now possible to set a blank section title format on the Build Novel Project tool and get empty paragraphs in the output. Previously, a blank format would just remove the section break entirely. This change allows the user to define hard and soft scene breaks using level three and four headings. The scene and section titles can be hidden completely with two new switches added to the user interface.

Other feature changes include:

✓ The project index is now automatically rebuilt in the event it is empty or incomplete when the project is opened.

✓ The user can now add their own syntax and GUI theme files in the app folder in their user area on the host operating system. Where the custom files must be added is described in the documentation.

✓ A Windows installer is yet again provided for novelWriter. If you have novelWriter installed using another method, make sure you uninstall it properly first as the two methods are not compatible.

✓ Release versions for Ubuntu 21.04 have been dropped, and added for the upcoming Ubuntu 22.04.

✓ Most translations have been updated. A Dutch translation is in the works.

See also the Releases page.